<?php
/**
 * Finance Accounting functions and definitions
 */

function finance_accounting_setup() {
	
	load_theme_textdomain( 'finance-accounting' );
	add_theme_support( 'automatic-feed-links' );
	add_theme_support( 'title-tag' );
	add_theme_support( 'woocommerce' );
	add_theme_support( 'post-thumbnails' );
	add_image_size( 'finance-accounting-featured-image', 2000, 1200, true );
	add_image_size( 'finance-accounting-thumbnail-avatar', 100, 100, true );

	// Set the default content width.
	$GLOBALS['content_width'] = 525;

	// This theme uses wp_nav_menu() in two locations.
	register_nav_menus( array(
		'top'    => __( 'Top Menu', 'finance-accounting' ),
	) );

	add_theme_support( 'html5', array(
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );

	add_theme_support( 'custom-logo', array(
		'width'       => 250,
		'height'      => 250,
		'flex-width'  => true,
	) );

	add_theme_support( 'custom-background', array(
		'default-color' => 'f1f1f1'
	) );

	// Add theme support for selective refresh for widgets.
	add_theme_support( 'customize-selective-refresh-widgets' );

	add_editor_style( array( 'assets/css/editor-style.css', finance_accounting_fonts_url() ) );
}
add_action( 'after_setup_theme', 'finance_accounting_setup' );


/**
 * Register custom fonts.
 */
function finance_accounting_fonts_url(){
	$font_url = '';
	$font_family = array();
	$font_family[] = 'PT Sans:300,400,600,700,800,900';
	$font_family[] = 'Roboto:400,700';
	$font_family[] = 'Montserrat:100,100i,200,200i,300,300i,400,400i,500,500i,600,600i,700,700i,800,800i,900,900i';
	$font_family[] = 'Lato';

	$query_args = array(
		'family'	=> rawurlencode(implode('|',$font_family)),
	);
	$font_url = add_query_arg($query_args,'//fonts.googleapis.com/css');
	return $font_url;
}

/**
 * Widget area.
 */
function finance_accounting_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Blog Sidebar', 'finance-accounting' ),
		'id'            => 'sidebox-1',
		'description'   => __( 'Add widgets here to appear in your sidebar on blog posts and archive pages.', 'finance-accounting' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );

	register_sidebar( array(
		'name'          => __( 'Page Sidebar', 'finance-accounting' ),
		'id'            => 'sidebox-2',
		'description'   => __( 'Add widgets here to appear in your sidebar on Pages and archive pages.', 'finance-accounting' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );

	register_sidebar( array(
		'name'          => __( 'Sidebar 3', 'finance-accounting' ),
		'id'            => 'sidebox-3',
		'description'   => __( 'Add widgets here to appear in your sidebar on blog posts and pages.', 'finance-accounting' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 1', 'finance-accounting' ),
		'id'            => 'footer-1',
		'description'   => __( 'Add widgets here to appear in your footer.', 'finance-accounting' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 2', 'finance-accounting' ),
		'id'            => 'footer-2',
		'description'   => __( 'Add widgets here to appear in your footer.', 'finance-accounting' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 3', 'finance-accounting' ),
		'id'            => 'footer-3',
		'description'   => __( 'Add widgets here to appear in your footer.', 'finance-accounting' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 4', 'finance-accounting' ),
		'id'            => 'footer-4',
		'description'   => __( 'Add widgets here to appear in your footer.', 'finance-accounting' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
}
add_action( 'widgets_init', 'finance_accounting_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function finance_accounting_scripts() {
	// Add custom fonts, used in the main stylesheet.
	wp_enqueue_style( 'finance-accounting-fonts', finance_accounting_fonts_url(), array(), null );

	//bootstrap
	wp_enqueue_style( 'bootstrap', get_theme_file_uri( '/assets/css/bootstrap.css' ));

	// Theme stylesheet.
	wp_enqueue_style( 'finance-accounting-style', get_stylesheet_uri() );

	//font-awesome 
	wp_enqueue_style( 'font-awesome', get_template_directory_uri().'/assets/css/fontawesome-all.css' );

	// Load the Internet Explorer 9 specific stylesheet, to fix display issues in the Customizer.
	if ( is_customize_preview() ) {
		wp_enqueue_style( 'finance-accounting-ie9', get_theme_file_uri( '/assets/css/ie9.css' ), array( 'finance-accounting-style' ), '1.0' );
		wp_style_add_data( 'finance-accounting-ie9', 'conditional', 'IE 9' );
	}

	// Load the Internet Explorer 8 specific stylesheet.
	wp_enqueue_style( 'finance-accounting-ie8', get_theme_file_uri( '/assets/css/ie8.css' ), array( 'finance-accounting-style' ), '1.0' );
	wp_style_add_data( 'finance-accounting-ie8', 'conditional', 'lt IE 9' );

	// Load the html5 shiv.
	wp_enqueue_script( 'html5', get_theme_file_uri( '/assets/js/html5.js' ), array(), '3.7.3' );
	wp_script_add_data( 'html5', 'conditional', 'lt IE 9' );

	wp_enqueue_script( 'finance-accounting-skip-link-focus-fix', get_theme_file_uri( '/assets/js/skip-link-focus-fix.js' ), array(), '1.0', true );

	$finance_accountingScreenReaderText=array();
	
	if ( has_nav_menu( 'top' ) ) {
		wp_enqueue_script( 'finance-accounting-navigation-jquery', get_theme_file_uri( '/assets/js/navigation.js' ), array( 'jquery' ), '1.0', true );

		$finance_accountingScreenReaderText['expand']         = __( 'Expand child menu', 'finance-accounting' );
		$finance_accountingScreenReaderText['collapse']       = __( 'Collapse child menu', 'finance-accounting' );
		
	}

	wp_enqueue_script( 'bootstrap', get_template_directory_uri() . '/assets/js/bootstrap.js', array('jquery') ,'',true);

	require get_parent_theme_file_path( '/color-option.php' );
	wp_add_inline_style( 'finance-accounting-style',$custom_css );

	wp_localize_script( 'finance-accounting-skip-link-focus-fix', 'finance_accountingScreenReaderText', $finance_accountingScreenReaderText );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'finance_accounting_scripts' );

/**
 * Front Page Template 
 */
function finance_accounting_front_page_template( $template ) {
	return is_home() ? '' : $template;
}
add_filter( 'frontpage_template',  'finance_accounting_front_page_template' );

function finance_accounting_sanitize_choices( $input, $setting ) {
    global $wp_customize; 
    $control = $wp_customize->get_control( $setting->id ); 
    if ( array_key_exists( $input, $control->choices ) ) {
        return $input;
    } else {
        return $setting->default;
    }
}

// Change number or products per row to 3
add_filter('loop_shop_columns', 'finance_accounting_loop_columns');
	if (!function_exists('finance_accounting_loop_columns')) {
	function finance_accounting_loop_columns() {
		return 3; // 3 products per row
	}
}

/* Excerpt Limit Begin */
function finance_accounting_string_limit_words($string, $word_limit) {
	$words = explode(' ', $string, ($word_limit + 1));
	if(count($words) > $word_limit)
	array_pop($words);
	return implode(' ', $words);
}

function finance_accounting_sanitize_dropdown_pages( $page_id, $setting ) {
  // Ensure $input is an absolute integer.
  $page_id = absint( $page_id );
  // If $page_id is an ID of a published page, return it; otherwise, return the default.
  return ( 'publish' == get_post_status( $page_id ) ? $page_id : $setting->default );
}

define('FINANCE_ACCOUNTING_LIVE_DEMO','https://www.themeseye.com/demo/finance-accounting/','finance-accounting');
define('FINANCE_ACCOUNTING_BUY_PRO','https://www.themeseye.com/wordpress/accounting-finance-wordpress-theme/','finance-accounting');
define('FINANCE_ACCOUNTING_PRO_SUPPORT','https://www.themeseye.com/forums/topic/finance-accounting-pro/','finance-accounting');
define('FINANCE_ACCOUNTING_FREE_SUPPORT','https://wordpress.org/support/theme/finance-accounting/','finance-accounting');

//footer Link
define('FINANCE_ACCOUNTING_CREDIT','https://www.themeseye.com/wordpress/free-finance-wordpress-theme/','finance-accounting');

if ( ! function_exists( 'finance_accounting_credit' ) ) {
	function finance_accounting_credit(){
		echo "<a href=".esc_url(FINANCE_ACCOUNTING_CREDIT)." target='_blank'>".esc_html__('Finance WordPress Theme','finance-accounting')."</a>";
	}
}

require get_parent_theme_file_path( '/inc/custom-header.php' );

require get_parent_theme_file_path( '/inc/template-tags.php' );

require get_parent_theme_file_path( '/inc/template-functions.php' );

require get_parent_theme_file_path( '/inc/customizer.php' );

require get_parent_theme_file_path( '/inc/dashboard/get_started_info.php' );